import type { Reducer, AnyAction } from 'redux';
import type { ThunkAction } from 'redux-thunk';
import AppRegistry from 'hadron-app-registry';
import type { WorkspacesServices } from '..';
import type { MyQueriesWorkspace } from '@mongodb-js/compass-saved-aggregations-queries';
import type { ServerStatsWorkspace } from '@mongodb-js/compass-serverstats';
import type { DatabasesWorkspace, CollectionsWorkspace } from '@mongodb-js/compass-databases-collections';
import type { CollectionWorkspace } from '@mongodb-js/compass-collection';
export type AnyWorkspace = MyQueriesWorkspace | ServerStatsWorkspace | DatabasesWorkspace | CollectionsWorkspace | CollectionWorkspace;
export type Workspace<T extends AnyWorkspace['type']> = Extract<AnyWorkspace, {
    type: T;
}>;
type WorkspacesThunkAction<R, A extends AnyAction = AnyAction> = ThunkAction<R, WorkspacesState, WorkspacesServices, A>;
export declare const getLocalAppRegistryForTab: (tabId: string) => AppRegistry;
export declare enum WorkspacesActions {
    OpenWorkspace = "compass-workspaces/OpenWorkspace",
    SelectTab = "compass-workspaces/SelectTab",
    SelectPreviousTab = "compass-workspaces/SelectPreviousTab",
    SelectNextTab = "compass-workspaces/SelectNextTab",
    MoveTab = "compass-workspaces/MoveTab",
    OpenTabFromCurrentActive = "compass-workspaces/OpenTabFromCurrentActive",
    CloseTab = "compass-workspaces/CloseTab",
    CollectionRenamed = "compass-workspaces/CollectionRenamed",
    CollectionRemoved = "compass-workspaces/CollectionRemoved",
    DatabaseRemoved = "compass-workspaces/DatabaseRemoved"
}
export type WorkspaceTab = {
    id: string;
} & AnyWorkspace;
export type WorkspacesState = {
    tabs: WorkspaceTab[];
    activeTabId: string | null;
};
export declare const getInitialTabState: (workspace: OpenWorkspaceOptions) => WorkspaceTab;
declare const reducer: Reducer<WorkspacesState>;
export declare const getActiveTabIndex: (state: WorkspacesState) => number;
export declare const getActiveTab: (state: WorkspacesState) => WorkspaceTab | null;
export type OpenWorkspaceOptions = Pick<Workspace<'My Queries'>, 'type'> | Pick<Workspace<'Databases'>, 'type'> | Pick<Workspace<'Performance'>, 'type'> | Pick<Workspace<'Collections'>, 'type' | 'namespace'> | Workspace<'Collection'>;
type OpenWorkspaceAction = {
    type: WorkspacesActions.OpenWorkspace;
    workspace: OpenWorkspaceOptions;
    newTab?: boolean;
};
export declare const openWorkspace: (workspaceOptions: OpenWorkspaceOptions, tabOptions?: {
    newTab?: boolean;
}) => OpenWorkspaceAction;
type SelectTabAction = {
    type: WorkspacesActions.SelectTab;
    atIndex: number;
};
export declare const selectTab: (atIndex: number) => SelectTabAction;
type MoveTabAction = {
    type: WorkspacesActions.MoveTab;
    fromIndex: number;
    toIndex: number;
};
export declare const moveTab: (fromIndex: number, toIndex: number) => MoveTabAction;
type SelectPreviousTabAction = {
    type: WorkspacesActions.SelectPreviousTab;
};
export declare const selectPrevTab: () => SelectPreviousTabAction;
type SelectNextTabAction = {
    type: WorkspacesActions.SelectNextTab;
};
export declare const selectNextTab: () => SelectNextTabAction;
type OpenTabFromCurrentActiveAction = {
    type: WorkspacesActions.OpenTabFromCurrentActive;
};
export declare const openTabFromCurrent: () => OpenTabFromCurrentActiveAction;
type CloseTabAction = {
    type: WorkspacesActions.CloseTab;
    atIndex: number;
};
export declare const closeTab: (atIndex: number) => WorkspacesThunkAction<void, CloseTabAction>;
type CollectionRenamedAction = {
    type: WorkspacesActions.CollectionRenamed;
    from: string;
    to: string;
};
export declare const collectionRenamed: (from: string, to: string) => WorkspacesThunkAction<void, CollectionRenamedAction>;
type CollectionRemovedAction = {
    type: WorkspacesActions.CollectionRemoved;
    namespace: string;
};
export declare const collectionRemoved: (namespace: string) => WorkspacesThunkAction<void, CollectionRemovedAction>;
type DatabaseRemovedAction = {
    type: WorkspacesActions.DatabaseRemoved;
    namespace: string;
};
export declare const databaseRemoved: (namespace: string) => WorkspacesThunkAction<void, DatabaseRemovedAction>;
export declare const emitOnTabChange: (newTab: WorkspaceTab) => WorkspacesThunkAction<void>;
export default reducer;
//# sourceMappingURL=workspaces.d.ts.map